@@ -14,6 +14,7 @@ from .._utils.path import prefix_relative_path
 from .._utils.timeout import with_timeout
 from ..common.errors import DaytonaError
 from ..common.protocols import SandboxCodeToolbox
+from .computer_use import AsyncComputerUse
 from .filesystem import AsyncFileSystem
 from .git import AsyncGit
 from .lsp_server import AsyncLspServer, LspLanguageId
@@ -27,6 +28,7 @@ class AsyncSandbox(SandboxDto):
         fs (AsyncFileSystem): File system operations interface.
         git (AsyncGit): Git operations interface.
         process (AsyncProcess): Process execution interface.
+        computer_use (AsyncComputerUse): Computer use operations interface for desktop automation.
         id (str): Unique identifier for the Sandbox.
         organization_id (str): Organization ID of the Sandbox.
         snapshot (str): Daytona snapshot used to create the Sandbox.
@@ -55,6 +57,7 @@ class AsyncSandbox(SandboxDto):
     _fs: AsyncFileSystem = PrivateAttr()
     _git: AsyncGit = PrivateAttr()
     _process: AsyncProcess = PrivateAttr()
+    _computer_use: AsyncComputerUse = PrivateAttr()
 
     # TODO: Remove model_config once everything is migrated to pydantic # pylint: disable=fixme
     model_config = ConfigDict(arbitrary_types_allowed=True)
@@ -85,6 +88,7 @@ class AsyncSandbox(SandboxDto):
         self._fs = AsyncFileSystem(self.id, toolbox_api, self.__get_root_dir)
         self._git = AsyncGit(self.id, toolbox_api, self.__get_root_dir)
         self._process = AsyncProcess(self.id, code_toolbox, toolbox_api, self.__get_root_dir)
+        self._computer_use = AsyncComputerUse(self.id, toolbox_api)
 
     @property
     def fs(self) -> AsyncFileSystem:
@@ -98,6 +102,10 @@ class AsyncSandbox(SandboxDto):
     def process(self) -> AsyncProcess:
         return self._process
 
+    @property
+    def computer_use(self) -> AsyncComputerUse:
+        return self._computer_use
+
     async def refresh_data(self) -> None:
         """Refreshes the Sandbox data from the API.
 
@@ -204,8 +212,8 @@ class AsyncSandbox(SandboxDto):
             print("Sandbox started successfully")
             ```
         """
-        await self._sandbox_api.start_sandbox(self.id, _request_timeout=timeout or None)
-        await self.refresh_data()
+        sandbox = await self._sandbox_api.start_sandbox(self.id, _request_timeout=timeout or None)
+        self.__process_sandbox_dto(sandbox)
         await self.wait_for_sandbox_start()
 
     @intercept_errors(message_prefix="Failed to stop sandbox: ")
@@ -267,6 +275,9 @@ class AsyncSandbox(SandboxDto):
         while self.state != "started":
             await self.refresh_data()
 
+            if self.state == "started":
+                return
+
             if self.state in ["error", "build_failed"]:
                 err_msg = (
                     f"Sandbox {self.id} failed to start with state: {self.state}, error reason: {self.error_reason}"
